from lecrapaud.models.base import Base
from lecrapaud.models.experiment import Experiment
from lecrapaud.models.feature_selection_rank import FeatureSelectionRank
from lecrapaud.models.feature_selection import FeatureSelection
from lecrapaud.models.feature import Feature
from lecrapaud.models.model_selection import ModelSelection
from lecrapaud.models.model import Model
from lecrapaud.models.model_selection_score import ModelSelectionScore
from lecrapaud.models.target import Target

__all__ = [
    "Base",
    "Experiment",
    "FeatureSelectionRank",
    "FeatureSelection",
    "Feature",
    "ModelSelection",
    "Model",
    "ModelSelectionScore",
    "Target",
]



"""add bias to score

Revision ID: 9a191ae1c27d
Revises: 0a8fb7826e9b
Create Date: 2025-12-16 16:44:18.903577

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '9a191ae1c27d'
down_revision: Union[str, None] = '0a8fb7826e9b'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('lecrapaud_model_selection_scores', sa.Column('bias', sa.Float(), nullable=True))
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('lecrapaud_model_selection_scores', 'bias')
    # ### end Alembic commands ###
